aboutsummaryrefslogtreecommitdiffhomepage
path: root/Firestore/Source/Public/FIRTransaction.h
diff options
context:
space:
mode:
Diffstat (limited to 'Firestore/Source/Public/FIRTransaction.h')
-rw-r--r--Firestore/Source/Public/FIRTransaction.h11
1 files changed, 5 insertions, 6 deletions
diff --git a/Firestore/Source/Public/FIRTransaction.h b/Firestore/Source/Public/FIRTransaction.h
index 51a6e90..2fa4430 100644
--- a/Firestore/Source/Public/FIRTransaction.h
+++ b/Firestore/Source/Public/FIRTransaction.h
@@ -20,7 +20,6 @@ NS_ASSUME_NONNULL_BEGIN
@class FIRDocumentReference;
@class FIRDocumentSnapshot;
-@class FIRSetOptions;
/**
* `FIRTransaction` provides methods to read and write data within a transaction.
@@ -50,19 +49,19 @@ NS_SWIFT_NAME(Transaction)
/**
* Writes to the document referred to by `document`. If the document doesn't yet exist,
* this method creates it and then sets the data. If you pass `FIRSetOptions`, the provided data
* will be merged into an existing document.
*
* @param data An `NSDictionary` that contains the fields and data to write to the document.
* @param document A reference to the document whose data should be overwritten.
- * @param options A `FIRSetOptions` used to configure the set behavior.
+ * @param merge Whether to merge the provided data into any existing document.
* @return This `FIRTransaction` instance. Used for chaining method calls.
*/
// clang-format off
- (FIRTransaction *)setData:(NSDictionary<NSString *, id> *)data
forDocument:(FIRDocumentReference *)document
- options:(FIRSetOptions *)options
- NS_SWIFT_NAME(setData(_:forDocument:options:));
+ merge:(BOOL)merge
+ NS_SWIFT_NAME(setData(_:forDocument:merge:));
// clang-format on
/**
@@ -50,19 +49,19 @@ NS_SWIFT_NAME(Transaction)
/**
* Writes to the document referred to by `document`. If the document doesn't yet exist,
- * this method creates it and then sets the data. If you pass `FIRSetOptions`, the provided data
- * will be merged into an existing document.
+ * this method creates it and then sets the data. If you pass `merge:YES`, the provided data will be
+ * merged into any existing document.
*
* @param data An `NSDictionary` that contains the fields and data to write to the document.